Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type RangeMap ¶
type RangeMap[T any] struct { // contains filtered or unexported fields }
RangeMap - A Map that is very useful when its needed to make a map from a key ranging from a set of values
func (*RangeMap[T]) Get ¶
Get - returns the value stored in the map for a key, or nil if no value is present. The ok result indicates whether value was found in the map.
func (*RangeMap[T]) GetOrDefault ¶
GetOrDefault - returns the value for a key. If the key does not exist, returns the default value instead.
Click to show internal directories.
Click to hide internal directories.